@@ -1,13 +1,14 @@
-// 	$Id: BoolNetBatchSwarm.h,v 1.1.1.1 1998/01/08 00:56:14 alex Exp $	
+// 	$Id: BoolNetBatchSwarm.h,v 1.2 1998/02/04 21:56:50 mgd Exp $	
 
-#import <swarmobject.h>
+#import <objectbase.h>
 #import <activity.h>
 #import <collections.h>
 #import <simtools.h>
 #import <stdio.h>
 #import "BoolNetModelSwarm.h"
 
-@interface BoolNetBatchSwarm : Swarm {
+@interface BoolNetBatchSwarm: Swarm
+{
   int displayFrequency;
 
   id displayActions;	
