@@ -1,9 +1,9 @@
-// 	$Id: main.m,v 1.6 1998/03/30 23:17:21 alex Exp $	
+// 	$Id: main.m,v 1.7 1999/02/16 02:23:48 alex Exp $	
 
 #import "BoolNetObserverSwarm.h"
 #import "BoolNetBatchSwarm.h"
 #import <graph.h>
-#import <boolnet.h>
+#import <booleannet.h>
 #import <simtoolsgui.h>
 
 int
